@@ -1,6 +1,6 @@
 
 /*
- * Copyright 1993-2020 NVIDIA Corporation.  All rights reserved.
+ * Copyright 1993-2022 NVIDIA Corporation.  All rights reserved.
  *
  * NVIDIA CORPORATION and its licensors retain all intellectual property
  * and proprietary rights in and to this software, related documentation
@@ -15,7 +15,9 @@
 extern "C" {
 #endif
 #include "nv_fm_types.h"
-#define DECLDIR
+
+#define FM_LIB_API   __attribute__ ((visibility ("default")))
+
 /***************************************************************************************************/
 /** @defgroup FMAPI_Admin Administrative
  *   
@@ -35,7 +37,7 @@ extern "C" {
  *        - \ref FM_ST_IN_USE               FM API interface library is already in initialized state
  *        - \ref FM_ST_GENERIC_ERROR        A generic, unspecified error occurred
  */
-fmReturn_t DECLDIR fmLibInit(void);
+fmReturn_t FM_LIB_API fmLibInit(void);
 /**
  * This method is used to shut down the Fabric Manager API interface library. Any remote connections
  * established through fmConnect() will be shut down as well.
@@ -44,7 +46,7 @@ fmReturn_t DECLDIR fmLibInit(void);
  *        - \ref FM_ST_SUCCESS           if FM API interface library has been properly shut down
  *        - \ref FM_ST_UNINITIALIZED     FM API interface library was not in initialized state
  */
-fmReturn_t DECLDIR fmLibShutdown(void);
+fmReturn_t FM_LIB_API fmLibShutdown(void);
 /**
  * This method is used to connect to a running instance of Fabric Manager. Fabric Manager instance is
  * started as part of system service or manually by the SysAdmin. This connection will be used by the
@@ -68,7 +70,7 @@ fmReturn_t DECLDIR fmLibShutdown(void);
  *         - \ref FM_ST_BADPARAM               if pFmHandle is NULL or provided IP Address/format is invalid
  *         - \ref FM_ST_VERSION_MISMATCH       if the expected and provided versions of connectParams do not match
  */
- fmReturn_t DECLDIR fmConnect(fmConnectParams_t *connectParams, fmHandle_t *pFmHandle);
+ fmReturn_t FM_LIB_API fmConnect(fmConnectParams_t *connectParams, fmHandle_t *pFmHandle);
 /**
  * This method is used to disconnect from a Fabric Manager instance.
  *
@@ -80,7 +82,7 @@ fmReturn_t DECLDIR fmLibShutdown(void);
  *         - \ref FM_ST_BADPARAM            if pFmHandle is not a valid handle
  *         - \ref FM_ST_GENERIC_ERROR       if an unspecified internal error occurred
  */
-fmReturn_t DECLDIR fmDisconnect(fmHandle_t pFmHandle);
+fmReturn_t FM_LIB_API fmDisconnect(fmHandle_t pFmHandle);
 /** @} */ // Closing for FMAPI_Admin
 /******************************************************************************************************/
 /** @defgroup FMAPI_FabricPartition Fabric Partition Related APIs
@@ -107,7 +109,7 @@ fmReturn_t DECLDIR fmDisconnect(fmHandle_t pFmHandle);
  *         - \ref FM_ST_NOT_CONFIGURED      Fabric Manager instance is initializing and no data
  *         - \ref FM_ST_VERSION_MISMATCH    if the expected and provided versions of pFmFabricPartition do not match
  */
-fmReturn_t DECLDIR fmGetSupportedFabricPartitions(fmHandle_t pFmHandle, fmFabricPartitionList_t *pFmFabricPartition);
+fmReturn_t FM_LIB_API fmGetSupportedFabricPartitions(fmHandle_t pFmHandle, fmFabricPartitionList_t *pFmFabricPartition);
 /**
  * This method is used to activate an available fabric partition in an NVSwitch based system.
  *
@@ -125,7 +127,7 @@ fmReturn_t DECLDIR fmGetSupportedFabricPartitions(fmHandle_t pFmHandle, fmFabric
  *         - \ref FM_ST_IN_USE              specified partition is already active
  *         - \ref FM_ST_NVLINK_ERROR        NVLink error/training failure occurred when activating the partition
  */
-fmReturn_t DECLDIR fmActivateFabricPartition(fmHandle_t pFmHandle, fmFabricPartitionId_t partitionId);
+fmReturn_t FM_LIB_API fmActivateFabricPartition(fmHandle_t pFmHandle, fmFabricPartitionId_t partitionId);
 /**
  * This method is used to activate an available fabric partition with VFs in an NVSwitch based system.
  *
@@ -148,7 +150,7 @@ fmReturn_t DECLDIR fmActivateFabricPartition(fmHandle_t pFmHandle, fmFabricParti
  *         - \ref FM_ST_IN_USE              specified partition is already active
  *         - \ref FM_ST_NVLINK_ERROR        NVLink error/training failure occurred when activating the partition
  */
-fmReturn_t DECLDIR fmActivateFabricPartitionWithVFs(fmHandle_t pFmHandle, fmFabricPartitionId_t partitionId, fmPciDevice_t *vfList, unsigned int numVfs);
+fmReturn_t FM_LIB_API fmActivateFabricPartitionWithVFs(fmHandle_t pFmHandle, fmFabricPartitionId_t partitionId, fmPciDevice_t *vfList, unsigned int numVfs);
 /**
  * This method is used to deactivate a previously activated fabric partition in an NVSwitch based system.
  *
@@ -166,7 +168,7 @@ fmReturn_t DECLDIR fmActivateFabricPartitionWithVFs(fmHandle_t pFmHandle, fmFabr
  *         - \ref FM_ST_UNINITIALIZED       specified partition is not activated
  *         - \ref FM_ST_NVLINK_ERROR        NVLink error/training failure occurred when deactivating the partition
  */
-fmReturn_t DECLDIR fmDeactivateFabricPartition(fmHandle_t pFmHandle, fmFabricPartitionId_t partitionId);
+fmReturn_t FM_LIB_API fmDeactivateFabricPartition(fmHandle_t pFmHandle, fmFabricPartitionId_t partitionId);
 /**
  * This method is used to set a list of currently activated fabric partitions to Fabric Manager after its restart.
  * This call should be made with number of partitions as zero even if there is no active partitions
@@ -184,13 +186,16 @@ fmReturn_t DECLDIR fmDeactivateFabricPartition(fmHandle_t pFmHandle, fmFabricPar
  *         - \ref FM_ST_NOT_CONFIGURED      Fabric Manager is initializing and no data available.
  *         - \ref FM_ST_VERSION_MISMATCH    if the expected and provided versions of pFmActivatedPartitionList do not match
  */
-fmReturn_t DECLDIR fmSetActivatedFabricPartitions(fmHandle_t pFmHandle, fmActivatedFabricPartitionList_t *pFmActivatedPartitionList);
+fmReturn_t FM_LIB_API fmSetActivatedFabricPartitions(fmHandle_t pFmHandle, fmActivatedFabricPartitionList_t *pFmActivatedPartitionList);
 /**
  * This method is used to query all GPUs and NVSwitches with failed NVLinks as part of Fabric Manager initialization
  *
  * This API is not supported when Fabric Manager is running in Shared NVSwitch
  * multi-tenancy resiliency restart (--restart) mode
  *
+ * Note: On HGX H100 8-GPU based systems, NVLinks are trained at hardware level without higher level software coordination.
+ * So, Fabric Manager will always return an empty failed NVLink device list for this call on those systems.
+ *
  * @param pFmHandle IN:  Handle that came form \ref fmConnect
  *
  * @param pFmNvlinkFailedDevices  OUT: List of GPU or NVSwitch devices that have failed NVLinks
@@ -204,7 +209,7 @@ fmReturn_t DECLDIR fmSetActivatedFabricPartitions(fmHandle_t pFmHandle, fmActiva
  *         - \ref FM_ST_NOT_CONFIGURED      Fabric Manager instance is initializing and no data
  *         - \ref FM_ST_VERSION_MISMATCH    if the expected and provided versions of pFmFabricPartition do not match
  */
-fmReturn_t DECLDIR fmGetNvlinkFailedDevices(fmHandle_t pFmHandle, fmNvlinkFailedDevices_t *pFmNvlinkFailedDevices);
+fmReturn_t FM_LIB_API fmGetNvlinkFailedDevices(fmHandle_t pFmHandle, fmNvlinkFailedDevices_t *pFmNvlinkFailedDevices);
 /***************************************************************************************************/
 /**
  * This method is used to query all the unsupported fabric partitions when Fabric Manager is
@@ -223,7 +228,7 @@ fmReturn_t DECLDIR fmGetNvlinkFailedDevices(fmHandle_t pFmHandle, fmNvlinkFailed
  *         - \ref FM_ST_NOT_CONFIGURED      Fabric Manager instance is initializing and no data
  *         - \ref FM_ST_VERSION_MISMATCH    if the expected and provided versions of pFmFabricPartition do not match
  */
-fmReturn_t DECLDIR fmGetUnsupportedFabricPartitions(fmHandle_t pFmHandle,
+fmReturn_t FM_LIB_API fmGetUnsupportedFabricPartitions(fmHandle_t pFmHandle,
                                                     fmUnsupportedFabricPartitionList_t *pFmUnupportedFabricPartition);
 /** @} */ // Closing for FMAPI_FabricPartition
 #ifdef __cplusplus
